#  SAP LeanIX APIs
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/sap-leanix-apis#overview)
  * [REST APIs](https://help.sap.com/docs/leanix/ea/sap-leanix-apis#rest-apis)
  * [GraphQL API](https://help.sap.com/docs/leanix/ea/sap-leanix-apis#graphql-api)
  * [Integration API](https://help.sap.com/docs/leanix/ea/sap-leanix-apis#integration-api)


Explore SAP LeanIX APIs and learn when to use each API.
